# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.0.0] - 2024-08-14

### Changed

- Update development status to "stable"
- Update project links

## [0.3.0] - 2023-05-09

### Added

- Standalone script for repository distribution

### Changed

- Remove `build` command
- Remove `sync` command

## [0.2.0] - 2022-09-15

### Added

- Cosmetic logging submodule
- New `build` command
- New `sync` command

### Changed

- Refactor Bazel functions to submodule
- Remove dependency on colorama

## [0.1.0] - 2022-08-18

First release of the project.

[unreleased]: https://github.com/upkie/raspunzel/compare/v0.3.0...HEAD
[0.3.0]: https://github.com/upkie/raspunzel/compare/v0.2.0...v0.3.0
[0.2.0]: https://github.com/upkie/raspunzel/compare/v0.1.0...v0.2.0
[0.1.0]: https://github.com/upkie/raspunzel/releases/tag/v0.1.0
